## ----download, eval=FALSE------------------------------------------------
#  chooseCRANmirror(ind=1)
#  install.packages("BrailleR")

## ----update, eval=FALSE--------------------------------------------------
#  chooseCRANmirror(ind=1)
#  update.packages(ask=FALSE)

## ----start---------------------------------------------------------------
library(BrailleR)

## ----SetAuthor-----------------------------------------------------------
SetAuthor("Jonathan Godfrey")

